/*
 * Nombre del proyecto: Proyecto Arkanoid
 *
 * Nombre del fichero: general.h
 *
 * Nombre de los autores: Grzegorz Adam Hankiewicz y Carlos Pereda Moreno
 *
 * Fecha: 18 de Enero del 2000
 *
 * Descripcin: Fichero que contiene definiciones de constantes y macros
 * tiles para todo el cdigo. Por eso se incluye siempre.
 */

#ifndef GENERAL_H
#define GENERAL_H

/* Defines usados por las rutinas de configuracin y relacionadas */
#define NOMBRE_PROYECTO          "Proyecto Arkanoid"
#define ARKANOID_VERSION         1
#define ARKANOID_SUB_VERSION     0
#define AUTORES                  "Grzegorz Adam Hankiewicz - Carlos Pereda Moreno"
#define ARKANOID_CFG             "arkanoid.cfg"
#define SECCION_ARKANOID         "Proyecto_Arkanoid"
#define CFG_ANCHO_PANTALLA       "ancho_pantalla"
#define CFG_ALTO_PANTALLA        "alto_pantalla"
#define CFG_FICH_LOG             "fichero_log"

/* Algunos valores que usaremos por defecto durante el juego */
#define NUM_CADENAS_ERROR        10
#define NUM_MENSAJES_LOG         100

#define SMALL_STR                256
#define STR                      1024
#define BIG_STR                  10240

#define MINIMO_PANTALLA_X        300
#define MINIMO_PANTALLA_Y        200

/* Bits que se usan con la variable global 'banderas' */
#define BIT_SHOW_HELP            0x0001
#define BIT_LOGGING_ACTIVO       0x0002
#define BIT_MODO_GRAFICO         0x0004
#define BIT_LOG_A_FICHERO        0x0008
#define BIT_IGNORA_LOG           0x0010
#define BIT_COLISION_RAQUETA     0x0020
#define BIT_CAMBIO_RES           0x0040

/* Bits que se usan para la variable local parar_juego */
#define BIT_ESPERAR_BOLA         0x0010
#define BIT_SIGUIENTE_NIVEL      0x0020
#define BIT_GAME_OVER            0x0040
#define BIT_PERDER_VIDA          0x0080
#define BIT_SALIR_DE_JUEGO       0x0100

/* Macros para poner/leer/quitar bits de una variable */
#ifndef SET_FLAG
   #define SET_FLAG(x,f)         ((x)|=(f))
   #define GET_FLAG(x,f)         ((x)&(f))
   #define CLEAR_FLAG(x,f)       ((x)&= ~(f))
#endif

/* Definiciones de la pantalla virtual lgica */
#define RES_LOGICA_X             250
#define RES_LOGICA_Y             200
#define TAM_CELDA                5

/* Valores usados por los grficos del juego, a nivel lgico */
#define MAX_NIVELES              50
#define ANCHO_BOLA               5
#define ALTO_BOLA                5
#define F_ANCHO_BOLA             itofix (ANCHO_BOLA)
#define F_ALTO_BOLA              itofix (ANCHO_BOLA)
#define ANCHO_RAQUETA            40
#define F_ANCHO_RAQUETA          itofix (ANCHO_RAQUETA)
#define ALTO_RAQUETA             5
#define F_ALTO_RAQUETA           itofix (ALTO_RAQUETA)
#define ALTURA_RAQUETA           (RES_LOGICA_Y - 2*ALTO_RAQUETA)
#define F_ALTURA_RAQUETA         itofix (ALTURA_RAQUETA)
#define RAD_BOLA                 2
#define F_RAD_BOLA               itofix (RAD_BOLA)
#define INC_ANG_COLISION         itofix (8)
#define INC_VELOCIDAD            (1<<9)

/* Defines para movimiento y bits de botones activados/desactivados */

#define MAX_MOV                  127
#define BT_DISP1                 0x0001
#define BT_DISP2                 0x0002
#define BT_PAUSA                 0x0004
#define BT_ESC                   0x0008

#endif /* GENERAL_H */
